DDSketch

Struct DDSketch 

pub struct DDSketch { /* private fields */ }
This struct represents a DDSketch

Implementations

Source

impl DDSketch

pub fn new(config: Config) -> Self

Construct a DDSketch. Requires a Config specifying the parameters of the sketch

pub fn add(&mut self, v: f64)

Add the sample to the sketch

pub fn quantile(&self, q: f64) -> Result<Option<f64>, DDSketchError>

Return the quantile value for quantiles between 0.0 and 1.0. Result is an error, represented as DDSketchError::Quantile if the requested quantile is outside of that range.

If the sketch is empty the result is None, else Some(v) for the quantile value.

pub fn min(&self) -> Option<f64>

Returns the minimum value seen, or None if sketch is empty

pub fn max(&self) -> Option<f64>

Returns the maximum value seen, or None if sketch is empty

pub fn sum(&self) -> Option<f64>

Returns the sum of values seen, or None if sketch is empty

pub fn count(&self) -> usize

Returns the number of values added to the sketch

pub fn length(&self) -> usize

Returns the length of the underlying Store. This is mainly only useful for understanding how much the sketch has grown given the inserted values.

pub fn merge(&mut self, o: &DDSketch) -> Result<(), DDSketchError>

Merge the contents of another sketch into this one. The sketch that is merged into this one is unchanged after the merge.