pub struct DDSketch { /* private fields */ }Expand description
This struct represents a DDSketch
Implementations
Sourceimpl DDSketch
impl DDSketch
Sourcepub fn new(config: Config) -> Self
pub fn new(config: Config) -> Self
Construct a DDSketch. Requires a Config specifying the parameters of the sketch
Sourcepub fn quantile(&self, q: f64) -> Result<Option<f64>, DDSketchError>
pub fn quantile(&self, q: f64) -> Result<Option<f64>, DDSketchError>
Return the quantile value for quantiles between 0.0 and 1.0. Result is an error, represented as DDSketchError::Quantile if the requested quantile is outside of that range.
If the sketch is empty the result is None, else Some(v) for the quantile value.